@@ -12,7 +12,7 @@
 """
 from lxml import etree  # fast and furious xml library
 
-from .config import aaf_type, ConfigError, dbtype
+from .config import aaf_type, ConfigError, dbtype, support_educonnect, code_aca, format_projet_athos
 
 if dbtype in ["mysql", "sqlite"]:
     from .util import MinimalSQLGenerator as DataBaseGenerator
@@ -26,6 +26,8 @@ from .util import modif_fields, pwgen, log, db, \
 from .miscutil import user_id, classes_for_one_eleve, \
                                 groupe_eleve
 
+from .finduserldap import AgentLDAP
+
 
 # mode (complet ou mise a jour) pour l'importation
 # le mode d'utilisation peut être fixé de l'extérieur du module
@@ -181,13 +183,14 @@ def _parse_attrib_split(value, idx):
 
 
 def _parse_aaf_profadmin(usertype, userdata):
-
     if usertype == 'administratif':
         unused_fields = ['ENTAuxEnsClassesPrincipal', 'ENTAuxEnsCategoDiscipline',
             'ENTAuxEnsDisciplinesPoste', 'ENTAuxEnsGroupes',
            'ENTAuxEnsGroupesMatieres']
     else:
-        unused_fields = []
+        unused_fields = ["ENTAuxEnsClassesMatieres", "ENTAuxEnsGroupesMatieres"]
+    # 2025
+    unused_fields.extend(["ENTAuxEnsCategoDisciplineDate", "ENTPersonStructRattachDate", "ENTPersonFonctionsDate", "ENTPersonStructRattachDate", "ENTPersonCategorieEnseignantDate", "ENTAuxEnsMEFDate", "ENTAuxEnsClassesMatieresDate", "ENTAuxEnsGroupesMatieresDate", "ENTAuxEnsClassesPrincipalDate"])
     unused_fields.append('ENTPersonCategorieEnseignant')
     # AAF1D attributes
     unused_fields.extend(['ENTEnsFonctionDir', 'ENTEnsSpecialites', 'ENTPersonAutresPrenoms'])
@@ -213,8 +216,6 @@ def _parse_aaf_profadmin(usertype, userdata):
         if 'ENTPersonFonctions' in userdata:
             userdata['ENTPersonFonctions'] = _parse_functions(userdata['ENTPersonFonctions'], etab_buffer)
 
-
-
 def _mongo_fetch_value(value, tablename, filterby, tbuffer):
     if tbuffer is not None and value in tbuffer:
         new_value = tbuffer[value]
@@ -249,12 +250,17 @@ def _replace_id_by_reference(userdata, key, tablename, filterby, tbuffer=None):
 
 
 def _parse_aaf_student(userdata, uid, classes_buffer, groupes_buffer, eleves_responsable_buffer):
-
     unused_fields = ['ENTPersonAdresse', 'ENTPersonCodePostal', 'ENTPersonVille', 'ENTPersonPays', 'ENTEleveAdresseRel']
+    #2025
+    unused_fields.extend(['mail', 'ENTPersonStructRattachDate', "ENTAuxEnsCategoDisciplineDate"])
+    if not support_educonnect:
+        unused_fields.append('ENTPersonAdresse')
     # AAF1D attributes
     unused_fields.extend(['ENTEleveDateEntreeClasses', 'ENTEleveDateSortieClasses',
                           'ENTEleveEtudesSurveillees', 'ENTEleveGarderieMatin', 'ENTEleveGarderieSoir',
                           'ENTEleveRestaurantScolaire', 'ENTEleveTypeClasse'])
+    # Ajout Aix-Marseille
+    unused_fields.extend(['ENTEleveEnseignementsEtablissementsAccueil', 'ENTEleveDateEntreeStructRattach', 'ENTEleveDateSortieStructRattach'])
     for field in unused_fields:
         if field in userdata:
             del userdata[field]
@@ -270,6 +276,19 @@ def _parse_aaf_student(userdata, uid, classes_buffer, groupes_buffer, eleves_res
             groupe_eleve(userdata, groupes_buffer, uid)
         else:
             raise ConfigError("wrong or unknown aaf_type configuration value: {}".format(aaf_type))
+        if format_projet_athos:
+            # On renseigne aussi les groupes dans ENTPersonProfils car le schéma de l'AD n'accepte pas ENTEleveGroupes
+            if userdata.get('ENTEleveGroupes') is None:
+                userdata["ENTPersonProfils"] = ""
+            else:
+                RowPair = False; # on ne renseigne qu'un champ sur 2 (séparés par des $)
+                Groupes = []
+                for LigneEleveGroupes in userdata['ENTEleveGroupes'].strip().split('\n'):
+                    for RowGrp in LigneEleveGroupes.split('$'):
+                        if RowPair:
+                            Groupes.append(RowGrp)
+                        RowPair = not RowPair
+                userdata["ENTPersonProfils"] = "$".join(Groupes)
     else:
         if 'ENTEleveGroupes' in userdata:
             if userdata['ENTEleveGroupes'] == "":
@@ -323,6 +342,7 @@ def parse_aaf(type_, filename, aaftype):
     login_buffer = []
     rnd_buffer = list()
     context = etree.iterparse(filename, events=('end',), tag='addRequest')
+    conn_agent_ldap = AgentLDAP()
     for event, tdata in context:
         _type = tdata.find('operationalAttributes/attr/value').text
         if _type != aaftype:
@@ -341,7 +361,8 @@ def parse_aaf(type_, filename, aaftype):
             #Règle de répartition des personnes
             #cf. Annexe 4 (Alimentation depuis le SI MEN) version 4.2
             if userdata['PersEducNatPresenceDevantEleves'] == 'O' or \
-                   '$DOC$' in userdata['ENTPersonFonctions']:
+                   '$DOC$' in userdata['ENTPersonFonctions'] or \
+                   '$ENS$' in userdata['ENTPersonFonctions']:
                 usertype = 'enseignant'
             else:
                 usertype = 'administratif'
@@ -363,6 +384,11 @@ def parse_aaf(type_, filename, aaftype):
             if k1d in userdata:
                 userdata[k2d] = userdata[k1d]
                 del userdata[k1d]
+        if conn_agent_ldap.connexion and type_ == "enseignant" and 'mail' in userdata:
+            fagent = conn_agent_ldap.find_ldap_agent(userdata['mail'])
+            if fagent:
+                userdata['ENTPersonAlias'] = fagent[0].lower()
+                userdata['title'] = fagent[1]
 
         if not maj_mode or db_user == []:
             # new user
@@ -400,6 +426,15 @@ def parse_aaf(type_, filename, aaftype):
                 userdata['ENTEleveStatutEleve'] = 'SCOLAIRE'
                 userdata['ENTEleveStructRattachId'] = userdata['ENTEleveINE']
 
+            if support_educonnect:
+                # P.ROY (calcul du vecteur d'identité EduConnect -> employeeNumber)
+                fr_educ_tld_sco = (code_aca, "AC2D", userdata['ENTEleveStructRattachId'])
+                userdata['employeeNumber'] = "|".join(fr_educ_tld_sco)
+                # P.ROY (classe -> departmentNumber)
+                for classe in userdata['ENTEleveClasses']:
+                    userdata['departmentNumber'] = classe.split('$', 1)[1]
+                    break
+
             # TODO: on avait évoqué la possibilité de pouvoir limiter la création
             # aux responsables "1" & "2" (resp.split('$')[1] in ['1', '2'])
             # ce qui revient à être dans la liste
@@ -445,6 +480,7 @@ def parse_aaf(type_, filename, aaftype):
     login_buffer = []
 
     db.commit("user")
+    conn_agent_ldap.unbind()
     log.info("TOTAL : {} {}s".format(num, type_))
 
 # ____________________________________________________________
@@ -524,6 +560,8 @@ def parse_aaf_etab_educnat(etab_file):
         unused_fields = ['ENTStructureMailSI']
         # AAF1D attributes
         unused_fields.extend(['ENTEcoleCirconscription', 'ENTEcoleRPI', 'ENTEcoleSecteur', 'ENTEcoleCommune'])
+        # Ajout Aix-Marseille
+        unused_fields.extend(['ENTStructureCodeTypeStruct', 'ENTEtablissementCodeMinistereTutelle', 'ENTServAcCodeAcademie'])
         for field in unused_fields:
             if field in etablissement:
                 del etablissement[field]
