@@ -10,11 +10,11 @@ parsing des delas provenant des XML AAF
 """
 from lxml import etree # fast and furious xml library
 
-from eoleaaf.aaf import classes_for_one_eleve, classes_buffer, groupes_buffer, \
-                eleves_responsable_buffer
-from eoleaaf.util import pwgen, log, modif_fields, db, sqlgen, parse_multi, \
+from .aaf import classes_for_one_eleve, classes_buffer, groupes_buffer, \
+                eleves_responsable_buffer, sqlgen
+from .util import pwgen, log, modif_fields, db, parse_multi, \
         get_new_id, gen_user_login
-from eoleaaf.miscutil import eleve_id, groupe_eleve
+from .miscutil import user_id, groupe_eleve
 
 # ______________________________________________________________________________
 # eleves
@@ -30,7 +30,7 @@ def modify_request_eleve(eleve_file):
             log.info("%s pas un élève :(" % _type)
             continue
         #**Attention** identifier/id == ENTPersonJointure
-        eleve = eleve_id(televe)
+        eleve = user_id(televe)
         for attr in televe.findall('modifications/modification'):
             balise, vals = parse_multi(attr)
             eleve[balise] = vals
@@ -40,7 +40,7 @@ def modify_request_eleve(eleve_file):
 
         retrieved = True
         if db_eleve == []:
-            log.warn("ATTENTION: l'eleve {0} sensé être mis a jour "
+            log.warning("ATTENTION: l'eleve {0} sensé être mis a jour "
             "n'existe pas dans la base".format(eleve['id']))
             retrieved = False
 
@@ -54,7 +54,7 @@ def modify_request_eleve(eleve_file):
             if retrieved:
                 log.error("ATTENTION: l'eleve {0} aurait dû avoir un "
                     "uid".format(eleve['id']))
-            uid = eleve['uid'] = get_new_id()
+            uid = eleve['uid'] = get_new_id({}, sqlgen)
         else:
             # utilisé plus bas...
             uid = db_eleve['uid']
@@ -63,7 +63,7 @@ def modify_request_eleve(eleve_file):
             if retrieved:
                 log.error("ATTENTION: l'eleve {0} aurait dû avoir un "
                     "login".format(eleve['id']))
-            eleve['ENTPersonLogin'] = gen_user_login(eleve['sn'], eleve['givenName'], uid, 'eleve', eleve['id'])
+            eleve['ENTPersonLogin'] = gen_user_login(eleve['sn'], eleve['givenName'], uid, 'eleve', eleve['id'], sqlgen, {})
 
         # ____________________________________________________________
         # traitement de la classe (le champ classe est obligatoire)
@@ -79,15 +79,15 @@ def modify_request_eleve(eleve_file):
             # il faut inserer l'eleve quand mme (mme s'il n'existe pas
             # dans la database)
             try:
-                modif_fields(eleve, modif_type="DELTACREATE", tablename="eleve",
+                modif_fields(eleve, sqlgen, modif_type="DELTACREATE", tablename="eleve",
                             fromxml=True, db=db)
-            except Exception, msg:
+            except Exception as msg:
                 log.error("Erreur à l'ajout de l'élève %s : %s" % (eleve['id'], msg))
         else:
             # maj de l'élève retrouvé
             try:
-                modif_fields(eleve, modif_type="DELTAUPDATE", tablename="eleve", fromxml=True, db=db)
-            except Exception, msg:
+                modif_fields(eleve, sqlgen, modif_type="DELTAUPDATE", tablename="eleve", fromxml=True, db=db)
+            except Exception as msg:
                 log.error("Erreur à la modification de l'élève %s : %s" % (eleve['id'], msg))
 
         televe.clear()
@@ -107,8 +107,8 @@ def add_request_eleve(eleve_file):
             log.info("%s pas un élève :(" % _type)
             continue
         #**Attention** identifier/id == ENTPersonJointure
-        eleve = eleve_id(televe)
-        uid = eleve['uid'] = get_new_id()
+        eleve = user_id(televe)
+        uid = eleve['uid'] = get_new_id({}, sqlgen)
         eleve['userPassword'] = pwgen()
         attrs = televe.findall('attributes/attr')
         if attrs == []:
@@ -120,7 +120,7 @@ def add_request_eleve(eleve_file):
             balise, vals = parse_multi(attr)
             eleve[balise] = vals
 
-        eleve['ENTPersonLogin'] = gen_user_login(eleve['sn'], eleve['givenName'], uid, 'eleve', eleve['id'])
+        eleve['ENTPersonLogin'] = gen_user_login(eleve['sn'], eleve['givenName'], uid, 'eleve', eleve['id'], sqlgen, {})
 
         for resp in eleve['ENTElevePersRelEleve'].split('\n'):
             numresp = resp.split('$')[0]
@@ -139,9 +139,9 @@ def add_request_eleve(eleve_file):
         # ____________________________________________________________
         # traitement de eleve
         try:
-            modif_fields(eleve, modif_type="DELTACREATE", tablename="eleve",
+            modif_fields(eleve, sqlgen, modif_type="DELTACREATE", tablename="eleve",
                         fromxml=True, db=db)
-        except Exception, msg:
+        except Exception as msg:
             log.error("Erreur à l'ajout de l'élève %s : %s" % (eleve['id'], msg))
         televe.clear()
         while televe.getprevious() is not None:
@@ -161,7 +161,7 @@ def delete_request_eleve(eleve_file):
             log.info("%s pas un élève :(" % _type)
             continue
         #**Attention** identifier/id == ENTPersonJointure
-        eleve = eleve_id(televe)
+        eleve = user_id(televe)
         # il faut aller voir dans la base si les champs n'existent pas
         sql = sqlgen.where_from('eleve', 'id', 'id', eleve['id'])
         db_eleve = db.fetchone(sql)
@@ -172,9 +172,9 @@ def delete_request_eleve(eleve_file):
         # ____________________________________________________________
         # suppression effective de eleve
         try:
-            modif_fields(eleve, modif_type="DELTADELETE", tablename="eleve", fromxml=True,
+            modif_fields(eleve, sqlgen, modif_type="DELTADELETE", tablename="eleve", fromxml=True,
                          db=db)
-        except Exception, msg:
+        except Exception as msg:
             log.error("Erreur au moment de la suppression"
                     " de l'élève %s : %s" % (str(eleve['id']), str(msg) ))
         televe.clear()
@@ -195,7 +195,7 @@ def parse_delta_eleves(eleve_file):
     modify_request_eleve(eleve_file)
     log.info('suppression eleve')
     delete_request_eleve(eleve_file)
-    db.commit()
+    db.commit(None)
 
 # ______________________________________________________________________________
 # responsables
@@ -217,15 +217,15 @@ def add_request_responsable(responsables_file):
             log.info("%s n'est pas un responsable :(" % _type)
             continue
         respid = tresp.find('identifier/id').text
-        responsable['id'] = unicode(respid)
+        responsable['id'] = str(respid)
         for attr in tresp.findall('attributes/attr'):
             balise, vals = parse_multi(attr)
             responsable[balise] = vals
 
         # new calculated uid and password
-        responsable['uid'] = get_new_id()
+        responsable['uid'] = get_new_id({}, sqlgen)
         responsable['userPassword'] = pwgen()
-        responsable['ENTPersonLogin'] = gen_user_login(responsable['sn'], responsable['givenName'], responsable['uid'], 'responsable', responsable['id'])
+        responsable['ENTPersonLogin'] = gen_user_login(responsable['sn'], responsable['givenName'], responsable['uid'], 'responsable', responsable['id'], sqlgen, {})
         # ____________________________________________________________
         # remplissage des élèves associé au responsable
         # à partir des inforamtions bufferisées
@@ -238,9 +238,9 @@ def add_request_responsable(responsables_file):
         # ____________________________________________________________
         # database insert
         try:
-            modif_fields(responsable, modif_type="DELTACREATE", tablename="responsable",
+            modif_fields(responsable, sqlgen, modif_type="DELTACREATE", tablename="responsable",
                          fromxml=True, db=db)
-        except Exception, msg:
+        except Exception as msg:
             log.error("Erreur au moment de l'ajout"
                       " du responsable %s : %s" % (responsable['id'], msg))
         # ____________________________________________________________
@@ -267,7 +267,7 @@ def modify_request_responsable(responsables_file):
             log.info("%s n'est pas un responsable :(" % _type)
             continue
         respid = tresp.find('identifier/id').text
-        responsable['id'] = unicode(respid)
+        responsable['id'] = str(respid)
         for attr in tresp.findall('modifications/modification'):
             balise, vals = parse_multi(attr)
             responsable[balise] = vals
@@ -277,7 +277,7 @@ def modify_request_responsable(responsables_file):
 
         retrieved = True
         if db_resp == []:
-            log.warn("ATTENTION: le responsable {0} sensé être mis a jour "
+            log.warning("ATTENTION: le responsable {0} sensé être mis a jour "
             "n'existe pas dans la base".format(responsable['id']))
             retrieved = False
 
@@ -285,28 +285,28 @@ def modify_request_responsable(responsables_file):
             responsable['userPassword'] = pwgen()
 
         if 'uid' not in db_resp:
-            responsable['uid'] = get_new_id()
+            responsable['uid'] = get_new_id({}, sqlgen)
 
         if 'ENTPersonLogin' not in db_resp:
             if retrieved:
                 log.error("ATTENTION: le responsable {0} aurait dû avoir un "
                     "login".format(responsable['id']))
-            responsable['ENTPersonLogin'] = gen_user_login(responsable['sn'], responsable['givenName'], responsable['uid'], 'responsable', responsable['id'])
+            responsable['ENTPersonLogin'] = gen_user_login(responsable['sn'], responsable['givenName'], responsable['uid'], 'responsable', responsable['id'], sqlgen, {})
 
         if not retrieved:
             # création du responsable non retrouvé
             try:
-                modif_fields(responsable, modif_type="DELTACREATE", tablename="responsable",
+                modif_fields(responsable, sqlgen, modif_type="DELTACREATE", tablename="responsable",
                              fromxml=True, db=db)
-            except Exception, msg:
+            except Exception as msg:
                 log.error("Erreur au moment de la modification"
                           " du responsable %s : %s" % (responsable['id'], msg))
         else:
             # maj du responsable retrouvé
             try:
-                modif_fields(responsable, modif_type="DELTAUPDATE", tablename="responsable",
+                modif_fields(responsable, sqlgen, modif_type="DELTAUPDATE", tablename="responsable",
                              fromxml=True, db=db)
-            except Exception, msg:
+            except Exception as msg:
                 log.error("Erreur au moment de la modification"
                           " du responsable %s : %s" % (responsable['id'], msg))
         # ____________________________________________________________
@@ -328,7 +328,7 @@ def delete_request_responsable(responsables_file):
             log.info("%s pas un responsable :(" % _type)
             continue
         #**Attention** identifier/id == ENTPersonJointure
-        responsable = eleve_id(tresponsable)
+        responsable = user_id(tresponsable)
         # il faut aller voir dans la base si les champs n'existent pas
         sql = sqlgen.where_from('responsable', 'id', 'id', responsable['id'])
         db_responsable = db.fetchone(sql)
@@ -339,9 +339,9 @@ def delete_request_responsable(responsables_file):
         # ____________________________________________________________
         # suppression effective de responsable
         try:
-            modif_fields(responsable, modif_type="DELTADELETE",
+            modif_fields(responsable, sqlgen, modif_type="DELTADELETE",
                         tablename="responsable", fromxml=True, db=db)
-        except Exception, msg:
+        except Exception as msg:
             log.error("Erreur au moment de la suppression"
                       " du responsable %s : %s" % (responsable['id'], msg))
         tresponsable.clear()
@@ -361,7 +361,7 @@ def parse_delta_responsables(responsables_file):
     modify_request_responsable(responsables_file)
     log.info('suppression responsable')
     delete_request_responsable(responsables_file)
-    db.commit()
+    db.commit(None)
 
 
 def add_request_profs(profs_file):
@@ -381,7 +381,7 @@ def add_request_profs(profs_file):
 
         #identifier/id == ENTPersonJointure
         profid = tprof.find('identifier/id').text
-        professeur = {'id':unicode(profid)}
+        professeur = {'id':str(profid)}
         classes = []
         matieres = []
         options = []
@@ -391,7 +391,7 @@ def add_request_profs(profs_file):
             balise, vals = parse_multi(attr)
             professeur[balise] = vals
         # new calculated uid and password
-        professeur['uid'] = get_new_id()
+        professeur['uid'] = get_new_id({}, sqlgen)
         professeur['userPassword'] = pwgen()
 
         #Règle de répartition des personnes
@@ -401,14 +401,14 @@ def add_request_profs(profs_file):
             usertype = 'enseignant'
         else:
             usertype = 'administratif'
-        professeur['ENTPersonLogin'] = gen_user_login(professeur['sn'], professeur['givenName'], professeur['uid'], usertype, professeur['id'])
+        professeur['ENTPersonLogin'] = gen_user_login(professeur['sn'], professeur['givenName'], professeur['uid'], usertype, professeur['id'], sqlgen, {})
 
         if usertype == 'enseignant':
             # c'est un enseignant
             try:
-                modif_fields(professeur, modif_type="DELTACREATE", tablename="enseignant",
+                modif_fields(professeur, sqlgen, modif_type="DELTACREATE", tablename="enseignant",
                             fromxml=True, db=db)
-            except Exception, msg:
+            except Exception as msg:
                 log.info("Erreur sur l'enseignant <%s>, "
                 "(explicit database msg : %s)" % (profid, msg))
         else:
@@ -419,9 +419,9 @@ def add_request_profs(profs_file):
             if 'ENTAuxEnsGroupes' in professeur:
                 del(professeur['ENTAuxEnsGroupes'])
             try:
-                modif_fields(professeur, modif_type="DELTACREATE",
+                modif_fields(professeur, sqlgen, modif_type="DELTACREATE",
                              tablename="administratif", fromxml=True, db=db)
-            except Exception, msg:
+            except Exception as msg:
                 log.info("Erreur sur le personnel <%s>, "
                 "(explicit database msg : %s)" % (profid, msg))
 
@@ -444,7 +444,7 @@ def modify_request_prof(profs_file):
         #identifier/id == ENTPersonJointure
         administratif = True
         profid = tprof.find('identifier/id').text
-        professeur = {'id':unicode(profid)}
+        professeur = {'id':str(profid)}
         classes = []
         matieres = []
         options = []
@@ -469,7 +469,7 @@ def modify_request_prof(profs_file):
 
         retrieved = True
         if db_ens == []:
-            log.warn("ATTENTION: le personnel {1} {0} sensé être mis a jour "
+            log.warning("ATTENTION: le personnel {1} {0} sensé être mis a jour "
             "n'existe pas dans la base".format(professeur['id'], usertype))
             retrieved = False
 
@@ -477,29 +477,28 @@ def modify_request_prof(profs_file):
             professeur['userPassword'] = pwgen()
 
         if 'uid' not in db_ens:
-            professeur['uid'] = get_new_id()
+            professeur['uid'] = get_new_id({}, sqlgen)
 
         if 'ENTPersonLogin' not in db_ens:
             if retrieved:
-                log.error("ATTENTION: le personnel {1} {0} aurait dû avoir un "
-                    "login".format(responsable['id'], usertype))
-            professeur['ENTPersonLogin'] = gen_user_login(professeur['sn'], professeur['givenName'], professeur['uid'], usertype, professeur['id'])
+                log.error("ATTENTION: le personnel {0} aurait dû avoir un login".format(usertype))
+            professeur['ENTPersonLogin'] = gen_user_login(professeur['sn'], professeur['givenName'], professeur['uid'], usertype, professeur['id'], sqlgen, {})
 
         if usertype == 'enseignant':
             if not retrieved:
                 # création de l'enseignant non retrouvé
                 try:
-                    modif_fields(professeur, modif_type="DELTACREATE",
+                    modif_fields(professeur, sqlgen, modif_type="DELTACREATE",
                             tablename="enseignant", fromxml=True, db=db)
-                except Exception, msg:
+                except Exception as msg:
                     log.info("Erreur sur l'enseignant <%s>, "
                     "(explicit database msg : %s)" % ( profid, str(msg) ))
             else:
                 # maj de l'enseignant retrouvé
                 try:
-                    modif_fields(professeur, modif_type="DELTAUPDATE",
+                    modif_fields(professeur, sqlgen, modif_type="DELTAUPDATE",
                             tablename="enseignant", fromxml=True, db=db)
-                except Exception, msg:
+                except Exception as msg:
                     log.info("Erreur sur l'enseignant <%s>, "
                     "(explicit database msg : %s)" % ( profid, str(msg) ))
         else:
@@ -512,17 +511,17 @@ def modify_request_prof(profs_file):
             if not retrieved:
                 # création de l'administratif non retrouvé
                 try:
-                    modif_fields(professeur, modif_type="DELTACREATE",
+                    modif_fields(professeur, sqlgen, modif_type="DELTACREATE",
                                  tablename="administratif", fromxml=True, db=db)
-                except Exception, msg:
+                except Exception as msg:
                     log.info("Erreur sur le personnel <%s>, "
                     "(explicit database msg : %s)" % (profid, msg))
             else:
                 # maj de l'administratif retrouvé
                 try:
-                    modif_fields(professeur, modif_type="DELTAUPDATE",
+                    modif_fields(professeur, sqlgen, modif_type="DELTAUPDATE",
                                  tablename="administratif", fromxml=True, db=db)
-                except Exception, msg:
+                except Exception as msg:
                     log.info("Erreur sur le personnel <%s>, "
                     "(explicit database msg : %s)" % (profid, msg))
         tprof.clear()
@@ -543,7 +542,7 @@ def delete_request_prof(profs_file):
             log.info("%s n'est pas un personnel " % _type)
             continue
         #**Attention** identifier/id == ENTPersonJointure
-        prof = eleve_id(tprof)
+        prof = user_id(tprof)
         # il faut aller voir dans les tables enseignant ou administratif
         # si l'entrée existe
         sql = sqlgen.where_from('enseignant', 'id', 'id', prof['id'])
@@ -560,7 +559,7 @@ def delete_request_prof(profs_file):
         # ____________________________________________________________
         # suppression effective du personnel
         try:
-            modif_fields(prof, modif_type="DELTADELETE", tablename=table,
+            modif_fields(prof, sqlgen, modif_type="DELTADELETE", tablename=table,
                          fromxml=True, db=db)
         except Exception:
             log.error("Erreur au moment de la suppression"
@@ -583,7 +582,7 @@ def parse_delta_profs(profs_file):
     modify_request_prof(profs_file)
     log.info('suppression professeur')
     delete_request_prof(profs_file)
-    db.commit()
+    db.commit(None)
 
 # ____________________________________________________________
 # etablissements
@@ -599,7 +598,7 @@ def add_request_etab_educnat(etab_file):
             log.info("%s n'est pas un etablissement :(" % _type)
             continue
         etabid = tresp.find('identifier/id').text
-        etablissement['id'] = unicode(etabid)
+        etablissement['id'] = str(etabid)
         for attr in tresp.findall('attributes/attr'):
             balise, vals = parse_multi(attr)
             etablissement[balise] = vals
@@ -608,7 +607,7 @@ def add_request_etab_educnat(etab_file):
             continue
         # database insert
         try:
-            modif_fields(etablissement, modif_type="DELTACREATE", tablename="etablissement",
+            modif_fields(etablissement, sqlgen, modif_type="DELTACREATE", tablename="etablissement",
                         fromxml=True, db=db)
         except Exception:
             log.error("Erreur au moment de l'ajout"
@@ -629,7 +628,7 @@ def modify_request_etab_educnat(etab_file):
             log.info("%s n'est pas un etablissement :(" % _type)
             continue
         etabid = tresp.find('identifier/id').text
-        etablissement['id'] = unicode(etabid)
+        etablissement['id'] = str(etabid)
         for attr in tresp.findall('modifications/modification'):
             balise, vals = parse_multi(attr)
             etablissement[balise] = vals
@@ -644,7 +643,7 @@ def modify_request_etab_educnat(etab_file):
             # il faut inserer l'etablissement quand mme (mme s'il n'existe pas
             # dans la database)
             try:
-                modif_fields(etablissement,  modif_type="DELTACREATE",
+                modif_fields(etablissement, sqlgen, modif_type="DELTACREATE",
                              tablename="etablissement", fromxml=True, db=db)
             except Exception:
                 log.error("Erreur au moment de la modification"
@@ -652,7 +651,7 @@ def modify_request_etab_educnat(etab_file):
             continue
         # database insert
         try:
-            modif_fields(etablissement,  modif_type="DELTAUPDATE",
+            modif_fields(etablissement, sqlgen, modif_type="DELTAUPDATE",
                          tablename="etablissement", fromxml=True, db=db)
         except Exception:
             log.error("Erreur au moment de la modification"
@@ -672,4 +671,4 @@ def parse_delta_etab_educnat(etab_file):
     add_request_etab_educnat(etab_file)
     log.info('modification etablissement')
     modify_request_etab_educnat(etab_file)
-    db.commit()
+    db.commit(None)
