@@ -21,7 +21,7 @@ from eoleaaf.ldiftranslator import LdifTranslator, gen_group_cn, \
     gen_group_owner, gen_user_cn, gen_user_displayname
 from eoleaaf.config import template_path, ldap_delta_create_filename, \
     ldap_delta_update_filename, ldap_delta_delete_filename, usersdn, \
-    entservac_structures, dbtype
+    entservac_structures, dbtype, import_responsable
 from eoleaaf.util import clean_empty_keys, modif_fields, \
     SimpleConnectionWrapper, log_error, make_datetime, log
 
@@ -55,7 +55,7 @@ def ldif_export_all(ldif_dir):
             dico = translator.translate_one('etablissement', row)
             siren[dico['ENTStructureJointure_ori']] = dico['ENTStructureSIREN']
             uai[dico['ENTStructureJointure_ori']] = dico['ENTStructureUAI']
-            dico = clean_empty_keys(dico)
+            dico = clean_empty_keys(dico, db, row["id"])
             try:
                 #Répartition des structures entre ENTEtablissement et ENTServAc
                 #en fonction de l'attribut ENTStructureTypeStruct
@@ -80,7 +80,7 @@ def ldif_export_all(ldif_dir):
         ch = CheetahTemplate.compile(file=join(template_path, 'classe.ldif'))
         for row in db.fetchtable('classe'):
             dico = translator.translate_one('classe', row)
-            dico = clean_empty_keys(dico)
+            dico = clean_empty_keys(dico, db, row["description"])
             try:
                 dico['cn'] = gen_group_cn(dico['description_ori'], siren)
                 dico['owner'] = gen_group_owner(dico['description_ori'], uai)
@@ -109,7 +109,7 @@ def ldif_export_all(ldif_dir):
         ch = CheetahTemplate.compile(file=join(template_path, "groupe.ldif"))
         for row in db.fetchtable('groupe'):
             dico = translator.translate_one('groupe', row)
-            dico = clean_empty_keys(dico)
+            dico = clean_empty_keys(dico, db, row["description"])
             try:
                 dico['cn'] = gen_group_cn(dico['description_ori'], siren)
                 dico['owner'] = gen_group_owner(dico['description_ori'], uai)
@@ -156,7 +156,7 @@ def ldif_export_all(ldif_dir):
             if 'ENTEleveMajeur' not in dico:
                 dico['ENTEleveMajeur'] = "N"
             # FIXME: optimization needed ?
-            dico = clean_empty_keys(dico)
+            dico = clean_empty_keys(dico, db, row["id"])
 
             for key in fixmekeys:
                 if key in dico:
@@ -175,30 +175,31 @@ def ldif_export_all(ldif_dir):
 
     sys.stderr.write("Lecture des responsables...\n")
 
-    with open(join(ldif_dir, '05-responsable.ldif'), 'w') as fh:
-        ch = CheetahTemplate.compile(file=join(template_path, "responsable.ldif"))
-        for row in db.fetchtable('responsable'):
-            dico = translator.translate_one('responsable', row)
-            try:
-                # FIXME XXX HAAAACK pour autoriser le prénom vide alors qu'il
-                # est supposé être obligatoire dans les préconisations du SDET.
-                if dico['givenName'] is None:
-                    dico['givenName'] = "-"
-                if dico['sn'] is None:
-                    dico['sn'] = "-"
-                dico['cn'] = gen_user_cn(dico['sn'], dico['givenName'])
-                dico['displayName'] = gen_user_displayname(dico['sn'], dico['givenName'])
-                #dico['userPassword'] = pwgen()
-                dico = clean_empty_keys(dico)
-                fh.write(str(ch(searchList=[dico])))
-                modif_fields(row, sqlgen, modif_type="CREATE_DONE", tablename='responsable',
-                            fromxml=False, db=db, id_column='id')
-            except Exception as err:
-                datestr = make_datetime()
-                msg = "Erreur à la génération du LDIF (7): {0} pour le responsable {1}"
-                msg = msg.format(str(err), row['id'])
-                log_error('responsable', 'CREATE_DONE', datestr, db, row['id'],
-                          msg)
+    if import_responsable:
+        with open(join(ldif_dir, '05-responsable.ldif'), 'w') as fh:
+            ch = CheetahTemplate.compile(file=join(template_path, "responsable.ldif"))
+            for row in db.fetchtable('responsable'):
+                dico = translator.translate_one('responsable', row)
+                try:
+                    # FIXME XXX HAAAACK pour autoriser le prénom vide alors qu'il
+                    # est supposé être obligatoire dans les préconisations du SDET.
+                    if dico['givenName'] is None:
+                        dico['givenName'] = "-"
+                    if dico['sn'] is None:
+                        dico['sn'] = "-"
+                    dico['cn'] = gen_user_cn(dico['sn'], dico['givenName'])
+                    dico['displayName'] = gen_user_displayname(dico['sn'], dico['givenName'])
+                    #dico['userPassword'] = pwgen()
+                    dico = clean_empty_keys(dico, db, row["id"])
+                    fh.write(str(ch(searchList=[dico])))
+                    modif_fields(row, sqlgen, modif_type="CREATE_DONE", tablename='responsable',
+                                fromxml=False, db=db, id_column='id')
+                except Exception as err:
+                    datestr = make_datetime()
+                    msg = "Erreur à la génération du LDIF (7): {0} pour le responsable {1}"
+                    msg = msg.format(str(err), row['id'])
+                    log_error('responsable', 'CREATE_DONE', datestr, db, row['id'],
+                              msg)
 
     db.commit(None)
 
@@ -216,7 +217,7 @@ def ldif_export_all(ldif_dir):
             dico['cn'] = gen_user_cn(dico['sn'], dico['givenName'])
             dico['displayName'] = gen_user_displayname(dico['sn'], dico['givenName'])
             #dico['userPassword'] = pwgen()
-            dico = clean_empty_keys(dico)
+            dico = clean_empty_keys(dico, db, row["id"])
             try:
                 fh.write(str(ch(searchList=[dico])))
                 modif_fields(row, sqlgen, modif_type="CREATE_DONE", tablename='enseignant',
@@ -249,7 +250,7 @@ def ldif_export_all(ldif_dir):
             dico['cn'] = gen_user_cn(dico['sn'], dico['givenName'])
             dico['displayName'] = gen_user_displayname(dico['sn'], dico['givenName'])
             #dico['userPassword'] = pwgen()
-            dico = clean_empty_keys(dico)
+            dico = clean_empty_keys(dico, db, row["id"])
             # le choix est déterminé par la présence d'une "structure de rattachement"
             # /!\ si dico['ENTPersonStructRattach'] vaut None, la clé est supprimée par "clean_empty_keys"
             try:
@@ -269,6 +270,7 @@ def ldif_export_all(ldif_dir):
 
     db.commit(None)
 
+
 def ldif_export_maj(ldif_dir):
     """point d'entrée de l'insertion des deltas dans le ldap, à savoir:
 
@@ -417,7 +419,7 @@ def ldif_export_factory(export_type, dbname, ldif_dir, ldif_template, ldif_filen
                     dico['sn'] = "-"
                 dico['cn'] = gen_user_cn(dico['sn'], dico['givenName'])
                 dico['displayName'] = gen_user_displayname(dico['sn'], dico['givenName'])
-            dico = clean_empty_keys(dico)
+            dico = clean_empty_keys(dico, db, row["id"])
             for key in fixmekeys:
                 if key in dico:
                     del(dico[key])
